@@ -1386,9 +1386,11 @@ func TestPackfileInfoForRepository(t *testing.T) {
 				Size:              hashDependentSize(t, 163, 189),
 				ReverseIndexCount: 1,
 				MultiPackIndex: MultiPackIndexInfo{
-					Exists:        true,
-					Version:       1,
-					PackfileCount: 1,
+					Exists:            true,
+					Version:           1,
+					PackfileCount:     1,
+					HasBitmappedPacks: false,
+					HasReverseIndex:   false,
 				},
 			},
 		},
@@ -1403,9 +1405,11 @@ func TestPackfileInfoForRepository(t *testing.T) {
 				Size:              hashDependentSize(t, 163, 189),
 				ReverseIndexCount: 1,
 				MultiPackIndex: MultiPackIndexInfo{
-					Exists:        true,
-					Version:       1,
-					PackfileCount: 1,
+					Exists:            true,
+					Version:           1,
+					PackfileCount:     1,
+					HasBitmappedPacks: true,
+					HasReverseIndex:   true,
 				},
 				MultiPackIndexBitmap: BitmapInfo{
 					Exists:       true,
@@ -1431,9 +1435,11 @@ func TestPackfileInfoForRepository(t *testing.T) {
 				GarbageCount:      1,
 				GarbageSize:       1,
 				MultiPackIndex: MultiPackIndexInfo{
-					Exists:        true,
-					Version:       1,
-					PackfileCount: 2,
+					Exists:            true,
+					Version:           1,
+					PackfileCount:     2,
+					HasBitmappedPacks: true,
+					HasReverseIndex:   true,
 				},
 				MultiPackIndexBitmap: BitmapInfo{
 					Exists:       true,
@@ -1456,9 +1462,11 @@ func TestPackfileInfoForRepository(t *testing.T) {
 				CruftCount:        1,
 				CruftSize:         hashDependentSize(t, 156, 183),
 				MultiPackIndex: MultiPackIndexInfo{
-					Exists:        true,
-					Version:       1,
-					PackfileCount: 2,
+					Exists:            true,
+					Version:           1,
+					PackfileCount:     2,
+					HasBitmappedPacks: true,
+					HasReverseIndex:   true,
 				},
 				MultiPackIndexBitmap: BitmapInfo{
 					Exists:       true,
