@@ -8,22 +8,22 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/featureflag"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/git"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/git/gittest"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/git/localrepo"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/gitaly/storage"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/gitaly/transaction"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/grpc/metadata"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/helper/text"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/signature"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/structerr"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/testhelper"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/testhelper/testcfg"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/testhelper/testserver"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/transaction/txinfo"
-	"gitlab.com/gitlab-org/gitaly/v16/internal/transaction/voting"
-	"gitlab.com/gitlab-org/gitaly/v16/proto/go/gitalypb"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/featureflag"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/git"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/git/gittest"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/git/localrepo"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/gitaly/storage"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/gitaly/transaction"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/grpc/metadata"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/helper/text"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/signature"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/structerr"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/testhelper"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/testhelper/testcfg"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/testhelper/testserver"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/transaction/txinfo"
+	"gitlab.com/gitlab-org/gitaly/v18/internal/transaction/voting"
+	"gitlab.com/gitlab-org/gitaly/v18/proto/go/gitalypb"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/types/known/timestamppb"
@@ -156,7 +156,12 @@ func testUserSquashTransactional(t *testing.T, ctx context.Context) {
 			voteFn: func(ctx context.Context, tx txinfo.Transaction, vote voting.Vote, phase voting.Phase) error {
 				return errors.New("vote failed")
 			},
-			expectedErr: structerr.NewAborted("preparatory vote on squashed commit: vote failed"),
+			// This gets intercepted by the Aborted interceptor which replaces the error message
+			// "preparatory vote on squashed commit: vote failed"
+			expectedErr: testhelper.ToInterceptedMetadata(
+				structerr.NewAborted("The operation could not be completed. Please try again.").WithMetadata(
+					"error_details", "preparatory vote on squashed commit: vote failed"),
+			),
 			expectedVotes: []voting.Vote{
 				squashedCommitVote,
 			},
@@ -170,7 +175,12 @@ func testUserSquashTransactional(t *testing.T, ctx context.Context) {
 				}
 				return nil
 			},
-			expectedErr: structerr.NewAborted("committing vote on squashed commit: vote failed"),
+			// This gets intercepted by the Aborted interceptor which replaces the error message
+			// "committing vote on squashed commit: vote failed"
+			expectedErr: testhelper.ToInterceptedMetadata(
+				structerr.NewAborted("The operation could not be completed. Please try again.").WithMetadata(
+					"error_details", "committing vote on squashed commit: vote failed"),
+			),
 			expectedVotes: []voting.Vote{
 				squashedCommitVote,
 				squashedCommitVote,
